@@ -8,12 +8,6 @@ PROJECTNAME = 'PloneInvite'
 UNIQUE_ID = 'plone_invite' 
 TOOLNAME = "Portal Invite Tool"
 
-# If you fill in the INVITE_EMAIL, this e-mail address will be set as the
-# plone_invite_email_address when the products is installed. If not, that
-# property will be set to equal the site's e-mail address. See Install.py for
-# install procedure.
-INVITE_EMAIL = ''
-
 SET_PORTAL_PERMISSIONS= (
     (InvitePortalUsers, ('Authenticated',), 1),
     (ManageMemberInvites, ('Authenticated',), 1),
